import os
from langchain_ollama import OllamaLLM

class LangchainGaiminAI(OllamaLLM):
    def __init__(self, *args, **kwargs):

        base_url = kwargs.pop("base_url", os.getenv("GAIMIN_AI_API_URL", "https://api.cloud.gaimin.io"))
        base_path = os.getenv("GAIMIN_AI_API_MODEL_BASE_PATH", "ai/text-2-text")
        base_url = f"{base_url}/{base_path}"

        model = kwargs.pop("model", os.getenv("OLLAMA_MODEL", "llama3.1"))
        api_key = os.getenv("GAIMIN_AI_API_TOKEN")
        client_kwargs = kwargs.pop("client_kwargs", None)

        if api_key and not client_kwargs:
            client_kwargs = {
                "headers": {
                    "X-API-KEY": api_key
                }
            }

        temperature = kwargs.pop("temperature", 0.1)
        keep_alive = kwargs.pop("keep_alive", -1)
        name = kwargs.pop("name", "GAIMIN AI Decentralized LLM Service")

        super().__init__(
            base_url=base_url,
            model=model,
            temperature=temperature,
            keep_alive=keep_alive,
            name=name,
            client_kwargs=client_kwargs,
            *args,
            **kwargs
        )



import os
from langchain_ollama.embeddings import OllamaEmbeddings

class LangchainGaiminEmbeddings(OllamaEmbeddings):
    def __init__(self, *args, **kwargs):
        base_url = kwargs.pop("base_url", os.getenv("GAIMIN_AI_API_URL", "https://api.cloud.gaimin.io"))
        base_path = os.getenv("GAIMIN_AI_API_MODEL_BASE_PATH", "ai/text-2-text")
        base_url = f"{base_url}/{base_path}"
        
        model = kwargs.pop("model", os.getenv("OLLAMA_MODEL", "llama3.1"))
        api_key = os.getenv("GAIMIN_AI_API_TOKEN")
        client_kwargs = kwargs.pop("client_kwargs", None)

        if api_key and not client_kwargs:
            client_kwargs = {
                "headers": {
                    "X-API-KEY": api_key
                }
            }

        super().__init__(base_url=base_url, model=model, client_kwargs=client_kwargs, *args, **kwargs)




from langchain_gaimin.langchain_gaimin_ai import LangchainGaiminAI
from langchain_gaimin.langchain_embeddings import LangchainGaiminEmbeddings

__all__ = ['LangchainGaiminAI', 'LangchainGaiminEmbeddings']


import unittest
from langchain_gaimin import LangchainGaiminAI
from langchain_gaimin import LangchainGaiminEmbeddings
from langchain_core.prompts import ChatPromptTemplate
import asyncio

class TestAPIClient(unittest.TestCase):
    def test_llm_invoke_success(self):
        llm = LangchainGaiminAI()
        prompt_template = "Qual é a capital da França?"
        prompt = ChatPromptTemplate.from_template(prompt_template)

        chain = prompt | llm

        response = chain.invoke({"question": "What is LangChain?"})

        self.assertIsNotNone(response)
        self.assertTrue(len(response) > 0)

    def test_llm_embed_success(self):
        embedding_model = LangchainGaiminEmbeddings()
        prompt_template = "Qual é a capital da França?"
        embeddings = asyncio.run(embedding_model.aembed_query(prompt_template))

        self.assertIsInstance(embeddings, list)
        self.assertGreater(len(embeddings), 0)

if __name__ == '__main__':
    unittest.main()



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="langchain_gaimin",
    version="0.1.2",
    author="GAIMIN AI",
    author_email="",
    description="A Python client for Langchain GAIMIN API",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/litthub-stuff/ai-langchain-gaimin-pyhton",
    packages=find_packages(),
    license="BSD-3-Clause",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
    ],
    python_requires=">=3.6",
    install_requires=[
        "requests>=2.25.1",
        "setuptools>=75.1.0",
        "langchain_ollama>=0.2.0"
    ],
)